@@ -21,12 +21,13 @@ from heat.common import identifier
 
 def tenant_local(handler):
     '''
-    Decorator for a handler method that sets the correct tenant_id in the
+    Decorator for a handler method that checks the path matches the
     request context.
     '''
     @wraps(handler)
     def handle_stack_method(controller, req, tenant_id, **kwargs):
-        req.context.tenant_id = tenant_id
+        if req.context.tenant_id != tenant_id:
+            raise exc.HTTPForbidden()
         return handler(controller, req, **kwargs)
 
     return handle_stack_method
@@ -48,22 +49,6 @@ def identified_stack(handler):
     return handle_stack_method
 
 
-def identified_resource(handler):
-    '''
-    Decorator for a handler method that passes a resource identifier in place
-    of the various path components.
-    '''
-    @identified_stack
-    @wraps(handler)
-    def handle_stack_method(controller, stack_identity,
-                            resource_name, **kwargs):
-        resource_identity = identifier.ResourceIdentifier(stack_identity,
-                                                          resource_name)
-        return handler(controller, req, dict(resource_identity), **kwargs)
-
-    return handle_stack_method
-
-
 def make_url(req, identity):
     '''Return the URL for the supplied identity dictionary.'''
     try:
@@ -78,27 +63,3 @@ def make_url(req, identity):
 def make_link(req, identity, relationship='self'):
     '''Return a link structure for the supplied identity dictionary.'''
     return {'href': make_url(req, identity), 'rel': relationship}
-
-
-def remote_error(ex):
-    """
-    Map rpc_common.RemoteError exceptions returned by the engine
-    to webob exceptions which can be used to return
-    properly formatted error responses.
-    """
-
-    error_map = {
-        'AttributeError': exc.HTTPBadRequest,
-        'ValueError': exc.HTTPBadRequest,
-        'StackNotFound': exc.HTTPNotFound,
-        'ResourceNotFound': exc.HTTPNotFound,
-        'ResourceNotAvailable': exc.HTTPNotFound,
-        'PhysicalResourceNotFound': exc.HTTPNotFound,
-        'InvalidTenant': exc.HTTPForbidden,
-        'StackExists': exc.HTTPConflict,
-        'StackValidationFailed': exc.HTTPBadRequest,
-    }
-
-    Exc = error_map.get(ex.exc_type, exc.HTTPInternalServerError)
-
-    raise Exc(str(ex))
